package com.steerinfo.dil.controller;

import com.steerinfo.dil.feign.AmsFeign;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.framework.controller.RESTfulResult;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.math.BigDecimal;
import java.util.HashMap;
import java.util.Map;

/**
 * @author luobang
 * @create 2021-09-17 14:10
 */
@RestController
@RequestMapping("${api.version}/ams")
public class AMScontroller extends BaseRESTfulController {

    @Autowired
    AmsFeign amsFeign;

    /**
     * 违约规则
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("getBreachList")
    @ApiOperation(value = "展示违约列表")
    public RESTfulResult getBreachList(@RequestBody(required = false) Map<String, Object> mapValue,
                                       Integer pageNum,
                                       Integer pageSize,
                                       Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getBreachList(mapValue, pageNum, pageSize, apiId);
    }

    @PostMapping("addContractBreach")
    @ApiOperation(value = "新增违约规则")
    RESTfulResult addContractBreach(@RequestBody Map<String, Object> amsContractBreach) {
        return amsFeign.addContractBreach(amsContractBreach);
    }

    @PostMapping("deleteContractBreach/{breachId}")
    @ApiOperation(value = "逻辑删除违约规则")
    RESTfulResult deleteContractBreach(@PathVariable("breachId") BigDecimal breachId) {
        return amsFeign.deleteContractBreach(breachId);
    }

    @PostMapping("updateContractBreach")
    @ApiOperation(value = "修改违约规则")
    RESTfulResult updateContractBreach(@RequestBody Map<String, Object> amsContractBreach) {
        return amsFeign.updateContractBreach(amsContractBreach);
    }

    @PostMapping("selectBreachToUpdate/{breachId}")
    @ApiOperation(value = "查询违约规则")
    RESTfulResult selectBreachToUpdate(@PathVariable("breachId") BigDecimal breachId) {
        return amsFeign.selectBreachToUpdate(breachId);
    }


    /**
     * 港口装卸单价
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("getLoadUnloadPriceList")
    @ApiOperation(value = "展示港口装卸单价列表")
    public RESTfulResult getLoadUnloadPriceList(@RequestBody(required = false) Map<String, Object> mapValue,
                                                Integer pageNum,
                                                Integer pageSize,
                                                Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getLoadUnloadPriceList(mapValue, pageNum, pageSize, apiId);
    }

    @PostMapping("addLoadUnloadPrice")
    @ApiOperation(value = "新增港口装卸单价")
    RESTfulResult addLoadUnloadPrice(@RequestBody Map<String, Object> amsContractOtherPrice) {
        return amsFeign.addLoadUnloadPrice(amsContractOtherPrice);
    }

    @PostMapping("deleteLoadUnloadPrice/{priceId}")
    @ApiOperation(value = "逻辑删除港口装卸单价")
    RESTfulResult deleteLoadUnloadPrice(@PathVariable("priceId") BigDecimal priceId) {
        return amsFeign.deleteLoadUnloadPrice(priceId);
    }

    @PostMapping("updateLoadUnloadPrice")
    @ApiOperation(value = "修改港口装卸单价")
    RESTfulResult updateLoadUnloadPrice(@RequestBody Map<String, Object> amsContractOtherPrice) {
        return amsFeign.updateLoadUnloadPrice(amsContractOtherPrice);
    }

    @PostMapping("selectLoadUnloadPriceToUpdate/{priceId}")
    @ApiOperation(value = "查询港口装卸单价")
    RESTfulResult selectLoadUnloadPriceToUpdate(@PathVariable("priceId") BigDecimal priceId) {
        return amsFeign.selectLoadUnloadPriceToUpdate(priceId);
    }


    /**
     * 火运单价
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("getTrainPriceList")
    @ApiOperation(value = "展示火运单价列表")
    public RESTfulResult getTrainPriceList(@RequestBody(required = false) Map<String, Object> mapValue,
                                           Integer pageNum,
                                           Integer pageSize,
                                           Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getTrainPriceList(mapValue, pageNum, pageSize, apiId);
    }

    @PostMapping("addTrainPrice")
    @ApiOperation(value = "新增火运单价")
    RESTfulResult addTrainPrice(@RequestBody Map<String, Object> amsContractTrainPrice) {
        return amsFeign.addTrainPrice(amsContractTrainPrice);
    }

    @PostMapping("deleteTrainPrice/{priceId}")
    @ApiOperation(value = "逻辑删除火运单价")
    RESTfulResult deleteTrainPrice(@PathVariable("priceId") BigDecimal priceId) {
        return amsFeign.deleteTrainPrice(priceId);
    }

    @PostMapping("updateTrainPrice")
    @ApiOperation(value = "修改火运单价")
    RESTfulResult updateTrainPrice(@RequestBody Map<String, Object> amsContractTrainPrice) {
        return amsFeign.updateTrainPrice(amsContractTrainPrice);
    }

    @PostMapping("selectTrainPriceToUpdate/{priceId}")
    @ApiOperation(value = "通过id查询火运单价")
    RESTfulResult selectTrainPriceToUpdate(@PathVariable("priceId") BigDecimal priceId) {
        return amsFeign.selectTrainPriceToUpdate(priceId);
    }

    /**
     * 运费单价
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("getShipPriceList")
    @ApiOperation(value = "展示水运单价列表")
    public RESTfulResult getShipPriceList(@RequestBody(required = false) Map<String, Object> mapValue,
                                          Integer pageNum,
                                          Integer pageSize,
                                          Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getShipPriceList(mapValue, pageNum, pageSize, apiId);
    }

    @PostMapping("addShipPrice")
    @ApiOperation(value = "新增水运单价")
    RESTfulResult addShipPrice(@RequestBody Map<String, Object> amsContractTransportPrice) {
        return amsFeign.addShipPrice(amsContractTransportPrice);
    }

    @PostMapping("deleteShipPrice/{priceId}")
    @ApiOperation(value = "逻辑删除运费单价")
    RESTfulResult deleteShipPrice(@PathVariable("priceId") BigDecimal priceId) {
        return amsFeign.deleteShipPrice(priceId);
    }

    @PostMapping("updateShipPrice")
    @ApiOperation(value = "修改水运单价")
    RESTfulResult updateShipPrice(@RequestBody Map<String, Object> amsContractTransportPrice) {
        return amsFeign.updateShipPrice(amsContractTransportPrice);
    }

    @PostMapping("selectPriceToUpdate/{priceId}")
    @ApiOperation(value = "通过id查询运费单价")
    RESTfulResult selectPriceToUpdate(@PathVariable("priceId") BigDecimal priceId) {
        return amsFeign.selectPriceToUpdate(priceId);
    }

    @PostMapping("getTruckPriceList")
    @ApiOperation(value = "展示汽运单价列表")
    public RESTfulResult getTruckPriceList(@RequestBody(required = false) Map<String, Object> mapValue,
                                           Integer pageNum,
                                           Integer pageSize,
                                           Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getTruckPriceList(mapValue, pageNum, pageSize, apiId);
    }

    @PostMapping("addAmsContractTransportPrice")
    @ApiOperation(value = "新增汽运单价")
    RESTfulResult addAmsContractTransportPrice(@RequestBody Map<String, Object> amsContractTransportPrice) {
        return amsFeign.addAmsContractTransportPrice(amsContractTransportPrice);
    }

    @PostMapping("updateAmsContractTransportPrice")
    @ApiOperation(value = "修改汽运单价")
    RESTfulResult updateAmsContractTransportPrice(@RequestBody Map<String, Object> amsContractTransportPrice) {
        return amsFeign.updateAmsContractTransportPrice(amsContractTransportPrice);
    }


    @PostMapping("getPurchaseOrderList")
    @ApiOperation(value = "展示采购订单列表")
    public RESTfulResult getPurchaseOrderList(@RequestBody(required = false) Map<String, Object> mapValue,
                                              Integer pageNum,
                                              Integer pageSize,
                                              Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getPurchaseOrderList(mapValue, pageNum, pageSize, apiId);
    }

    /**
     * 下拉框
     * @return
     */
    @GetMapping("getAddressDeliveryAddress")
    @ApiOperation(value = "得到地址下拉")
    public RESTfulResult getAddressDeliveryAddress(){
        return amsFeign.getAddressDeliveryAddress();
    }

    @GetMapping("getShipperId")
    @ApiOperation(value = "得到托运人下拉")
    public RESTfulResult getShipperId(){
        return amsFeign.getShipperId();
    }

    @GetMapping("getCarrierId")
    @ApiOperation(value = "得到承运商下拉")
    public RESTfulResult getCarrierId(){
        return amsFeign.getCarrierId();
    }

    @GetMapping("getCapacityId")
    @ApiOperation(value = "获取船id下拉列表")
    public RESTfulResult getCapacityId(){
        return amsFeign.getCapacityId();
    }

    @GetMapping("getMaterialId")
    @ApiOperation(value = "得到物资下拉")
    public RESTfulResult getMaterialId(){
        return amsFeign.getMaterialId();
    }

    @GetMapping("getTruckCapacityId")
    @ApiOperation(value = "得到车牌号下拉")
    public RESTfulResult getTruckCapacityId(){
        return amsFeign.getTruckCapacityId();
    }

    @GetMapping("getLineId")
    @ApiOperation(value = "获取运输线路下拉列表")
    public RESTfulResult getLineId(){
        return amsFeign.getLineId();
    }
// ----------------------------------销售合同-------------------------------------------
    /**
     * 查询汽运单价信息
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("/amscontracttransportprices")
    @ApiOperation(value = "查询汽运单价信息")
    public RESTfulResult amscontracttransportprices(@RequestBody(required = false) Map<String, Object> mapValue,
                                       Integer pageNum,
                                       Integer pageSize,
                                       Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.amscontracttransportprices(mapValue, pageNum, pageSize, apiId);
    }

    /**
     * 新增汽运单价
     * @param mapVal
     * @return
     */
    @PostMapping("addAmsContractTransportUnitPrice")
    @ApiOperation(value = "新增汽运单价")
    RESTfulResult addAmsContractTransportUnitPrice(@RequestBody Map<String, Object> mapVal) {
        return amsFeign.addAmsContractTransportUnitPrice(mapVal);
    }
    @PostMapping("deleteAmsContractTransportPrice")
    @ApiOperation(value = "通过主键id删除汽运单价")
    RESTfulResult deleteAmsContractTransportPrice(BigDecimal priceId) {
        return amsFeign.deleteAmsContractTransportPrice(priceId);
    }

    /**
     * 通过主键修改汽运单价
     */
    @PostMapping("updateAmsContractTransportUnitPrice")
    @ApiOperation(value = "通过主键id修改汽运单价")
    RESTfulResult updateAmsContractTransportUnitPrice(@RequestBody(required = false) Map<String, Object> mapVal) {
        return amsFeign.updateAmsContractTransportUnitPrice(mapVal);
    }
    /**
     * 通过主键修改汽运单价
     */
    @PostMapping("batchUpdateTransportPriceByOilPrice")
    @ApiOperation(value = "油价联动导致运价变动，批量修改运价")
    RESTfulResult batchUpdateTransportPriceByOilPrice(@RequestBody(required = false) Map<String, Object> mapVal) {
        return amsFeign.batchUpdateTransportPriceByOilPrice(mapVal);
    }
    @GetMapping("getLineNo")
    @ApiOperation(value = "得到线路编号下拉")
    public RESTfulResult getLineNo(){
        return amsFeign.getLineNo();
    }
    @GetMapping("getCapacityNumber")
    @ApiOperation(value = "得到运力编号下拉")
    public RESTfulResult getCapacityNumber(){
        return amsFeign.getCapacityNumber();
    }
    @GetMapping("getDeliveryAddress")
    @ApiOperation(value = "得到收货地址下拉")
    public RESTfulResult getDeliveryAddress(){
        return amsFeign.getDeliveryAddress();
    }
    @PostMapping("/addAmsDispatchSaleOrder")
    RESTfulResult addAmsDispatchSaleOrder(@RequestBody(required = false) Map<String, Object> mapVal) {
        return amsFeign.addAmsDispatchSaleOrder(mapVal);
    }
    @GetMapping("getCarrierName")
    @ApiOperation(value = "得到承运商名称")
    public RESTfulResult getCarrierName(){
        return amsFeign.getCarrierName();
    }
    @PostMapping("getSaleOrderInfo")
    @ApiOperation(value = "查询汽运单价信息")
    public RESTfulResult getSaleOrderInfo(@RequestBody(required = false) Map<String, Object> mapValue,
                                                    Integer pageNum,
                                                    Integer pageSize,
                                                    Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getSaleOrderInfo(mapValue, pageNum, pageSize, apiId);
    }
    @PostMapping("getAmsSaleOrderApproved")
    @ApiOperation(value = "查询汽运单价信息")
    public RESTfulResult getAmsSaleOrderApproved(@RequestBody(required = false) Map<String, Object> mapValue,
                                          Integer pageNum,
                                          Integer pageSize,
                                          Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getAmsSaleOrderApproved(mapValue, pageNum, pageSize, apiId);
    }
    @PostMapping("getSaleOrderDetail")
    @ApiOperation(value = "查询汽运单价信息")
    public RESTfulResult getSaleOrderDetail(@RequestBody(required = false) Map<String, Object> mapValue,
                                                 Integer pageNum,
                                                 Integer pageSize,
                                                 Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getSaleOrderDetail(mapValue, pageNum, pageSize, apiId);
    }
    @PostMapping("uploadSaleOrder/{saleOrderId}")
    RESTfulResult uploadSaleOrder(@PathVariable("saleOrderId") BigDecimal saleOrderId) {
        return amsFeign.uploadSaleOrder(saleOrderId);
    }
    @PostMapping("/addAmsSaleOrder")
    RESTfulResult addAmsSaleOrder(@RequestBody(required = false) Map<String, Object> mapVal) {
        return amsFeign.addAmsSaleOrder(mapVal);
    }
    @PostMapping("getAmsSaleOrderBySaleOrderId/{saleOrderId}")
    RESTfulResult getAmsSaleOrderBySaleOrderId(@PathVariable("saleOrderId") BigDecimal saleOrderId) {
        return amsFeign.getAmsSaleOrderBySaleOrderId(saleOrderId);
    }
    @PostMapping("/updateAmsSaleOrder")
    RESTfulResult updateAmsSaleOrder(@RequestBody(required = false) Map<String, Object> mapVal) {
        return amsFeign.updateAmsSaleOrder(mapVal);
    }
    @PostMapping("deleteAmsSaleOrderBySaleOrderId/{saleOrderId}")
    RESTfulResult deleteAmsSaleOrderBySaleOrderId(@PathVariable("saleOrderId") BigDecimal saleOrderId) {
        return amsFeign.deleteAmsSaleOrderBySaleOrderId(saleOrderId);
    }
    @PostMapping("getSaleOrderUpdateLog")
    @ApiOperation(value = "查询汽运单价信息")
    public RESTfulResult getSaleOrderUpdateLog(@RequestBody(required = false) Map<String, Object> mapValue,
                                            Integer pageNum,
                                            Integer pageSize,
                                            Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getSaleOrderUpdateLog(mapValue, pageNum, pageSize, apiId);
    }
    @GetMapping("getShipperName")
    @ApiOperation(value = "得到发货单位下拉")
    public RESTfulResult getShipperName(){
        return amsFeign.getShipperName();
    }
    @GetMapping("getConsigneeCompanyName")
    @ApiOperation(value = "得到收货单位下拉")
    public RESTfulResult getConsigneeCompanyName(){
        return amsFeign.getConsigneeCompanyName();
    }
    @PostMapping("addAmsSaleOrderMaterial")
    RESTfulResult addAmsSaleOrderMaterial(@RequestBody(required = false) Map<String,Object> map) {
        return amsFeign.addAmsSaleOrderMaterial(map);
    }
    @PostMapping("getAmsSaleOrderMaterialBySaleOrderMaterialId/{saleOrderMaterialId}")
    RESTfulResult getAmsSaleOrderMaterialBySaleOrderMaterialId(@PathVariable("saleOrderMaterialId") BigDecimal saleOrderMaterialId) {
        return amsFeign.getAmsSaleOrderMaterialBySaleOrderMaterialId(saleOrderMaterialId);
    }
    @PostMapping("deleteAmsSaleOrderMaterialBySaleOrderMaterialId")
    RESTfulResult deleteAmsSaleOrderMaterialBySaleOrderMaterialId(BigDecimal saleOrderMaterialId) {
        return amsFeign.deleteAmsSaleOrderMaterialBySaleOrderMaterialId(saleOrderMaterialId);
    }
    @PostMapping("getAddress/{saleOrderMaterialId}")
    RESTfulResult getAddress(BigDecimal saleOrderMaterialId) {
        return amsFeign.getAddress(saleOrderMaterialId);
    }
    @PostMapping("updateAddress")
    RESTfulResult updateAddress(@RequestBody(required = false)Map<String,Object> map) {
        return amsFeign.updateAddress(map);
    }
    @PostMapping("getSalePlanInfo")
    @ApiOperation(value = "查询汽运单价信息")
    public RESTfulResult getSalePlanInfo(@RequestBody(required = false) Map<String, Object> mapValue,
                                               Integer pageNum,
                                               Integer pageSize,
                                               Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getSalePlanInfo(mapValue, pageNum, pageSize, apiId);
    }
    @PostMapping("addAmsSalePlan")
    RESTfulResult addAmsSalePlan(@RequestBody(required = false)Map<String,Object> map) {
        return amsFeign.addAmsSalePlan(map);
    }
    @PostMapping("getAmsSalePlanByPlanId/{planId}")
    RESTfulResult getAmsSalePlanByPlanId(BigDecimal planId) {
        return amsFeign.getAmsSalePlanByPlanId(planId);
    }
    @PostMapping("upadteAmsSalePlanByPlanId")
    RESTfulResult upadteAmsSalePlanByPlanId(@RequestBody(required = false)Map<String,Object> map) {
        return amsFeign.upadteAmsSalePlanByPlanId(map);
    }
    @PostMapping("deleteAmsSalePlanByPlanId")
    RESTfulResult deleteAmsSalePlanByPlanId(@RequestParam BigDecimal planId) {
        return amsFeign.deleteAmsSalePlanByPlanId(planId);
    }
    @GetMapping("getMaterialName")
    @ApiOperation(value = "得到收货单位下拉")
    public RESTfulResult getMaterialName(){
        return amsFeign.getMaterialName();
    }
    @GetMapping("getAreaName")
    @ApiOperation(value = "得到收货单位下拉")
    public RESTfulResult getAreaName(){
        return amsFeign.getAreaName();
    }

}
